<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el" sourcelanguage="en">
  <context>
    <name>CmdRobotAddToolShape</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="215"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="216"/>
      <source>Add tool</source>
      <translation>Προσθήκη εργαλείου</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="217"/>
      <source>Add a tool shape to the robot</source>
      <translation>Προσθήκη ενός σχήματος εργαλείου στο ρομπότ</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="158"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="159"/>
      <source>Place robot...</source>
      <translation>Τοποθέτηση ρομπότ...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="160"/>
      <source>Place a robot (experimental!)</source>
      <translation>Τοποθέτηση ενός ρομπότ (πειραματική!)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotCreateTrajectory</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="62"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="63"/>
      <source>Create trajectory</source>
      <translation>Δημιουργία τροχιάς</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="64"/>
      <source>Create a new empty trajectory </source>
      <translation>Δημιουργία μιας νέας κενής τροχιάς </translation>
    </message>
  </context>
  <context>
    <name>CmdRobotEdge2Trac</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="320"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="321"/>
      <source>Edge to Trajectory...</source>
      <translation>Ακμή της Τροχιάς...</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="322"/>
      <source>Generate a Trajectory from a set of edges</source>
      <translation>Δημιουργήστε μια Τροχιά από ένα σύνολο ακμών</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaCompact</name>
    <message>
      <location filename="../../CommandExport.cpp" line="50"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="51"/>
      <source>Kuka compact subroutine...</source>
      <translation>Συμπαγής υπορουτίνα Kuka...</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="52"/>
      <source>Export the trajectory as a compact KRL subroutine.</source>
      <translation>Εξαγωγή της τροχιάς ως μιας συμπαγούς υπορουτίνας KRL.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaFull</name>
    <message>
      <location filename="../../CommandExport.cpp" line="112"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="113"/>
      <source>Kuka full subroutine...</source>
      <translation>Πλήρης υπορουτίνα Kuka...</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="114"/>
      <source>Export the trajectory as a full KRL subroutine.</source>
      <translation>Εξαγωγή της τροχιάς ως μιας πλήρους υπορουτίνας KRL.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR125</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="174"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="175"/>
      <source>Kuka IR125</source>
      <translation>Ρομπότ Kuka IR125</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="176"/>
      <source>Insert a Kuka IR125 into the document.</source>
      <translation>Εισαγωγή ενός ρομπότ Kuka IR125 στο έγγραφο.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR16</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="93"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="94"/>
      <source>Kuka IR16</source>
      <translation>Ρομπότ Kuka IR16</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="95"/>
      <source>Insert a Kuka IR16 into the document.</source>
      <translation>Εισαγωγή ενός ρομπότ Kuka IR16 στο έγγραφο.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR210</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="134"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="135"/>
      <source>Kuka IR210</source>
      <translation>Ρομπότ Kuka IR210</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="136"/>
      <source>Insert a Kuka IR210 into the document.</source>
      <translation>Εισαγωγή ενός ρομπότ Kuka IR210 στο έγγραφο.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR500</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="51"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="52"/>
      <source>Kuka IR500</source>
      <translation>Ρομπότ Kuka IR500</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="53"/>
      <source>Insert a Kuka IR500 into the document.</source>
      <translation>Εισαγωγή ενός ρομπότ Kuka IR500 στο έγγραφο.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypoint</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="95"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="96"/>
      <source>Insert in trajectory</source>
      <translation>Εισαγωγή στην τροχιά</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="97"/>
      <source>Insert robot Tool location into trajectory</source>
      <translation>Εισαγωγή της θέσης του Εργαλείου ρομπότ στην τροχιά</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypointPreselect</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="152"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="153"/>
      <source>Insert in trajectory</source>
      <translation>Εισαγωγή στην τροχιά</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="154"/>
      <source>Insert preselection position into trajectory (W)</source>
      <translation>Εισαγωγή της θέσης προεπιλογής στην τροχιά (W)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotRestoreHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="104"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <location filename="../../Command.cpp" line="106"/>
      <source>Move to home</source>
      <translation>Μετακίνηση στην θέση εκκίνησης</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultOrientation</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="216"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="217"/>
      <source>Set default orientation</source>
      <translation>Ορισμός προεπιλεγμένου προσανατολισμού</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="218"/>
      <source>Set the default orientation for subsequent commands for waypoint creation</source>
      <translation>Ορισμός του προεπιλεγμένου προσανατολισμού για μεταγενέστερες εντολές δημιουργίας σημείου διέλευσης</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultValues</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="254"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="255"/>
      <source>Set default values</source>
      <translation>Ορισμός προεπιλεγμένων τιμών</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="256"/>
      <source>Set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
      <translation>Ορισμός προεπιλεγμένων τιμών ταχύτητας, επιτάχυνσης και συνέχειας για μεταγενέστερες εντολές δημιουργίας σημείου διέλευσης</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="55"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="56"/>
      <location filename="../../Command.cpp" line="57"/>
      <source>Set the home position</source>
      <translation>Ορισμός της θέσης εκκίνησης</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSimulate</name>
    <message>
      <location filename="../../Command.cpp" line="199"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="200"/>
      <source>Simulate a trajectory</source>
      <translation>Προσομοίωση μιας τροχιάς</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="201"/>
      <source>Run a simulation on a trajectory</source>
      <translation>Εκτέλεση μιας προσομοίωσης τροχιάς</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryCompound</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="431"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="432"/>
      <source>Trajectory compound...</source>
      <translation>Σύνθετη τροχιά...</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="433"/>
      <source>Group and connect some trajectories to one</source>
      <translation>Ομαδοποίηση και ένωση μερικών τροχιών σε μια</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryDressUp</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="384"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="385"/>
      <source>Dress-up trajectory...</source>
      <translation>Αναδιαμόρφωση τροχιάς...</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="386"/>
      <source>Create a dress-up object which overrides some aspects of a trajectory</source>
      <translation>Δημιουργήστε ένα αντικείμενο αναδιαμόρφωσης που αντικαθιστά κάποιες πτυχές μιας τροχιάς</translation>
    </message>
  </context>
  <context>
    <name>Gui::TaskView::TaskWatcherCommands</name>
    <message>
      <location filename="../../Workbench.cpp" line="53"/>
      <source>Trajectory tools</source>
      <translation>Εργαλεία τροχιάς</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="54"/>
      <source>Robot tools</source>
      <translation>Εργαλεία ρομπότ</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="55"/>
      <source>Insert Robot</source>
      <translation>Εισαγωγή Ρομπότ</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="75"/>
      <location filename="../../Command.cpp" line="124"/>
      <location filename="../../Command.cpp" line="224"/>
      <location filename="../../Command.cpp" line="253"/>
      <location filename="../../CommandExport.cpp" line="65"/>
      <location filename="../../CommandExport.cpp" line="127"/>
      <location filename="../../CommandInsertRobot.cpp" line="234"/>
      <location filename="../../CommandTrajectory.cpp" line="111"/>
      <location filename="../../CommandTrajectory.cpp" line="167"/>
      <location filename="../../CommandTrajectory.cpp" line="184"/>
      <location filename="../../CommandTrajectory.cpp" line="412"/>
      <source>Wrong selection</source>
      <translation>Λάθος επιλογή</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Select one Robot to set home position</source>
      <translation>Επιλέξτε ένα Ρομπότ για ορισμό της θέσης εκκίνησης</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="125"/>
      <source>Select one Robot</source>
      <translation>Επιλέξτε ένα Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="225"/>
      <location filename="../../Command.cpp" line="254"/>
      <location filename="../../CommandExport.cpp" line="66"/>
      <location filename="../../CommandExport.cpp" line="128"/>
      <location filename="../../CommandTrajectory.cpp" line="112"/>
      <source>Select one Robot and one Trajectory object.</source>
      <translation>Επιλέξτε ένα Ρομπότ και ένα Αντικείμενο Τροχιάς.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="230"/>
      <source>Trajectory not valid</source>
      <translation>Η τροχιά δεν είναι έγκυρη</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="231"/>
      <source>You need at least two waypoints in a trajectory to simulate.</source>
      <translation>Απαιτούνται τουλάχιστον δύο σημεία της τροχιά για προσομοίωση.</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="88"/>
      <location filename="../../CommandExport.cpp" line="150"/>
      <source>KRL file</source>
      <translation>Αρχείο KRL</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="89"/>
      <location filename="../../CommandExport.cpp" line="151"/>
      <source>All Files</source>
      <translation>Όλα τα Αρχεία</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="90"/>
      <location filename="../../CommandExport.cpp" line="152"/>
      <source>Export program</source>
      <translation>Εξαγωγή προγράμματος</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="235"/>
      <source>Select one robot and one shape or VRML object.</source>
      <translation>Επιλέξτε ένα ρομπότ και ένα σχήμα ή αντικείμενο VRML.</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="168"/>
      <location filename="../../CommandTrajectory.cpp" line="185"/>
      <source>Select one Trajectory object.</source>
      <translation>Επιλέξτε ένα αντικείμενο Τροχιάς.</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="191"/>
      <source>No preselection</source>
      <translation>Καμία προεπιλογή</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="192"/>
      <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
      <translation>Θα πρέπει να πραγματοποιήσετε αιώρηση πάνω από ένα γεωμετρικό σχήμα (Προεπιλογή) με το ποντίκι για να χρησιμοποιήσετε αυτήν την εντολή. Δείτε την τεκμηρίωση για λεπτομέρειες.</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="268"/>
      <source>Set default speed</source>
      <translation>Ορισμός προεπιλεγμένης τιμής ταχύτητας</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="269"/>
      <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
      <translation>ταχύτητα: (π.χ. 1 μέτρο/δευτερόλεπτο^2 ή 3 εκατοστά/δευτερόλεπτο^2)</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="278"/>
      <source>Set default continuity</source>
      <translation>Ορισμός προεπιλεγμένης τιμής συνέχειας</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="279"/>
      <source>continuous ?</source>
      <translation>συνεχής ;</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="285"/>
      <source>Set default acceleration</source>
      <translation>Ορισμός προεπιλεγμένης τιμής επιτάχυνσης</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="286"/>
      <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
      <translation>επιτάχυνση: (π.χ. 1 μέτρο/δευτερόλεπτο^2 ή 3 εκατοστά/δευτερόλεπτο^2)</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="413"/>
      <source>Select the Trajectory which you want to dress up.</source>
      <translation>Επιλέξτε την Τροχιά που θέλετε να αναδιαμορφώσετε.</translation>
    </message>
    <message>
      <location filename="../../ViewProviderTrajectory.cpp" line="164"/>
      <source>Modify</source>
      <translation>Τροποποίηση</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="81"/>
      <source>No robot files installed</source>
      <translation>Δεν έχουν εγκατασταθεί αρχεία ρομπότ</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="82"/>
      <source>Please visit %1 and copy the files to %2</source>
      <translation>Παρακαλώ επισκεφθείτε το %1 και αντιγράψτε τα αρχεία στο %2</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::DlgTrajectorySimulate</name>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="20"/>
      <source>Simulation</source>
      <translation>Προσομοίωση</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="58"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="89"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="120"/>
      <source>||</source>
      <translation>||</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="151"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="182"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="213"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="237"/>
      <source>%</source>
      <translation>%</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="272"/>
      <source>Type</source>
      <translation>Τύπος</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="277"/>
      <source>Name</source>
      <translation>Όνομα</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="282"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="287"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="292"/>
      <source>A</source>
      <translation>A</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.cpp" line="47"/>
      <source>TaskEdge2TracParameter</source>
      <translation type="unfinished">TaskEdge2TracParameter</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobot6Axis</name>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="14"/>
      <source>Form</source>
      <translation>Μορφή</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="22"/>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="69"/>
      <source>A2</source>
      <translation>Α2</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="116"/>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="163"/>
      <source>A4</source>
      <translation>Α4</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="210"/>
      <source>A5</source>
      <translation>A5</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="257"/>
      <source>A6</source>
      <translation>A6</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="313"/>
      <source>TCP: (200.23,300.23,400.23,234,343,343)</source>
      <translation>TCP: (200.23,300.23,400.23,234,343,343)</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="329"/>
      <source>Tool: (0,0,400,0,0,0)</source>
      <translation>Εργαλείο: (0,0,400,0,0,0)</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="345"/>
      <source>...</source>
      <translation>...</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.cpp" line="52"/>
      <source>TaskRobot6Axis</source>
      <translation type="unfinished">TaskRobot6Axis</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.cpp" line="46"/>
      <source>TaskRobotControl</source>
      <translation type="unfinished">TaskRobotControl</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.cpp" line="46"/>
      <source>TaskRobotMessages</source>
      <translation type="unfinished">TaskRobotMessages</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectory</name>
    <message>
      <location filename="../../TaskTrajectory.ui" line="20"/>
      <source>Form</source>
      <translation>Μορφή</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="58"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="89"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="120"/>
      <source>||</source>
      <translation>||</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="151"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="182"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="213"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="237"/>
      <source>%</source>
      <translation>%</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="254"/>
      <source>10 ms</source>
      <translation>10 χιλιοστά του δευτερολέπτου</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="259"/>
      <source>50 ms</source>
      <translation>50 χιλιοστά του δευτερολέπτου</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="264"/>
      <source>100 ms</source>
      <translation>100 χιλιοστά του δευτερολέπτου</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="269"/>
      <source>500 ms</source>
      <translation>500 χιλιοστά του δευτερολέπτου</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="274"/>
      <source>1 s</source>
      <translation>1 δευτερόλεπτο</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="291"/>
      <source>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</source>
      <translation>Θέση (200.23, 300.23, 400.23, 234, 343 ,343)</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="317"/>
      <source>Type</source>
      <translation>Τύπος</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="322"/>
      <source>Name</source>
      <translation>Όνομα</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="327"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="332"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="337"/>
      <source>A</source>
      <translation>A</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.cpp" line="44"/>
      <source>Trajectory</source>
      <translation type="unfinished">Trajectory</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.cpp" line="48"/>
      <source>Dress Up Parameter</source>
      <translation type="unfinished">Dress Up Parameter</translation>
    </message>
  </context>
  <context>
    <name>TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="14"/>
      <source>Form</source>
      <translation>Μορφή</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="29"/>
      <source>Hide / Show</source>
      <translation>Απόκρυψη / Εμφάνιση</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="47"/>
      <source>Edges: 0</source>
      <translation>Ακμές: 0</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="61"/>
      <source>Cluster: 0</source>
      <translation>Σύμπλεγμα: 0</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="72"/>
      <source>Sizing Value:</source>
      <translation>Τιμή Μεγέθους:</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="103"/>
      <source>Use orientation of edge</source>
      <translation>Χρήση του προσανατολισμού της ακμής</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.ui" line="14"/>
      <source>Form</source>
      <translation>Μορφή</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="37"/>
      <source>X+</source>
      <translation>X+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="56"/>
      <source>Y+</source>
      <translation>Y+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="75"/>
      <source>Z+</source>
      <translation>Z+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="94"/>
      <source>A+</source>
      <translation>A+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="113"/>
      <source>B+</source>
      <translation>B+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="132"/>
      <source>C+</source>
      <translation>C+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="151"/>
      <source>X-</source>
      <translation>X-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="170"/>
      <source>Y-</source>
      <translation>Y-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="189"/>
      <source>Z-</source>
      <translation>Z-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="208"/>
      <source>A-</source>
      <translation>A-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="227"/>
      <source>B-</source>
      <translation>B-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="246"/>
      <source>C-</source>
      <translation>C-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="258"/>
      <source>Tool 0</source>
      <translation>Εργαλείο 0</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="263"/>
      <source>Tool</source>
      <translation>Εργαλείο</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="268"/>
      <source>Base 0</source>
      <translation>Βάση 0</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="273"/>
      <source>Base</source>
      <translation>Βάση</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="278"/>
      <source>World</source>
      <translation>Κόσμος</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="287"/>
      <source>50mm / 5°</source>
      <translation>50 χιλιοστά / 5 μοίρες</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="292"/>
      <source>20mm / 2°</source>
      <translation>20 χιλιοστά / 2 μοίρες</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="297"/>
      <source>10mm / 1°</source>
      <translation>10 χιλιοστά / 1 μοίρα</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="302"/>
      <source>5mm / 0.5°</source>
      <translation>5 χιλιοστά / 0.5 μοίρες</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="307"/>
      <source>1mm / 0.1°</source>
      <translation>1 χιλιοστό / 0.1 μοίρες</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.ui" line="14"/>
      <source>Form</source>
      <translation>Μορφή</translation>
    </message>
    <message>
      <location filename="../../TaskRobotMessages.ui" line="20"/>
      <source>clear</source>
      <translation>εκκαθάριση</translation>
    </message>
  </context>
  <context>
    <name>TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="14"/>
      <source>Form</source>
      <translation>Μορφή</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="20"/>
      <source>Speed &amp; Acceleration:</source>
      <translation>Ταχύτητα &amp; Επιτάχυνση:</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="29"/>
      <source>Speed:</source>
      <translation>Ταχύτητα:</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="55"/>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="92"/>
      <source>Use</source>
      <translation>Χρήση</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="66"/>
      <source>Accel:</source>
      <translation>Επιτάχυνση:</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="102"/>
      <source>Don't change Cont</source>
      <translation>Διατήρηση της Συνέχειας</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="107"/>
      <source>Continues</source>
      <translation>Συνεχίζει</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="112"/>
      <source>Discontinues</source>
      <translation>Διακόπτεται</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="127"/>
      <source>Position and Orientation:</source>
      <translation>Θέση και Προσανατολισμός:</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="136"/>
      <source>(0,0,0),(0,0,0)</source>
      <translation>(0,0,0),(0,0,0)</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="149"/>
      <source>...</source>
      <translation>...</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="159"/>
      <source>Don't change Position &amp; Orientation</source>
      <translation>Διατήρηση Θέσης &amp; Προσανατολισμού</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="164"/>
      <source>Use Orientation</source>
      <translation>Χρήση Προσανατολισμού</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="169"/>
      <source>Add Position</source>
      <translation>Προσθήκη Θέσης</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="174"/>
      <source>Add Orientation</source>
      <translation>Προσθήκη Προσανατολισμού</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="49"/>
      <source>Robot</source>
      <translation>Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="50"/>
      <source>Insert Robots</source>
      <translation>Εισαγωγή Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="51"/>
      <source>&amp;Robot</source>
      <translation>&amp;Ρομπότ</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="52"/>
      <source>Export trajectory</source>
      <translation>Εξαγωγή τροχιάς</translation>
    </message>
  </context>
</TS>
